/**
 * Creates a validation functions that parses the Valibot schema of a form.
 *
 * @param schema A Valibot schema.
 *
 * @returns A validation function.
 */
export function valiForm(schema) {
    return async (values) => {
        try {
            await schema.parse(values);
            return {};
        }
        catch (error) {
            return error.issues.reduce((errors, issue) => ({
                ...errors,
                [issue.path.map(({ key }) => key).join('.')]: issue.message,
            }), {});
        }
    };
}
